@@ -24,11 +24,11 @@ static char *ffrom;
 static char *tto;
 
 /* 関数プロトタイプ */
-void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpdd);
+void compare_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
 
 /*******************************************************************************
 *******************************************************************************/
-void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpdd)
+void compare_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
 {
 	pipe_from = NULL;
 	pipe_to = NULL;
