@@ -64,7 +64,7 @@
 {\
 	if((from_open == true) && (to_open == true))\
 	{\
-		compare_hash(oparg, cpinfo, sdir, cpdd);\
+		compare_hash(oparg, sdir, cpinfo, cpdd);\
 	}\
 	else if(cpinfo->skip == false)\
 	{\
@@ -118,13 +118,13 @@ static _Bool to_open;
 char *write_now;
 
 /* 関数プロトタイプ */
-void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd);
+void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
 static void * read_thread_func(void *unknown);
 static void * do_md5_append(void *tmp);
 
 /*******************************************************************************
 *******************************************************************************/
-void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
+void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
 {
 	static struct stat stat_buf;
 	static _Bool filesystem_check = false;
@@ -174,6 +174,44 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		verify_option_check = true;
 	}
 
+	if(filesystem_check == false)
+	{
+		char *tofs_tmp = cpinfo->tofs;
+
+		if(tofs_tmp != NULL)
+		{
+			if
+			(
+				((tofs_tmp[0] == 'e') && (tofs_tmp[1] == 'x') && (tofs_tmp[2] == 't') && (tofs_tmp[3] == '4'))
+				||
+				((tofs_tmp[0] == 'x') && (tofs_tmp[1] == 'f') && (tofs_tmp[2] == 's'))
+				||
+				((tofs_tmp[0] == 'b') && (tofs_tmp[1] == 't') && (tofs_tmp[2] == 'r') && (tofs_tmp[2] == 'f') && (tofs_tmp[2] == 's'))
+				||
+				((tofs_tmp[0] == 'o') && (tofs_tmp[1] == 'c') && (tofs_tmp[2] == 'f') && (tofs_tmp[2] == 's') && (tofs_tmp[2] == '2'))
+			)
+			{
+				fallocate_support = true;
+			}
+			else if
+			(
+				((tofs_tmp[0] == 'n') && (tofs_tmp[1] == 't') && (tofs_tmp[2] == 'f') && (tofs_tmp[3] == 's'))
+				||
+				((tofs_tmp[0] == 'f') && (tofs_tmp[1] == 'u') && (tofs_tmp[2] == 's') && (tofs_tmp[3] == 'e') && (tofs_tmp[4] == 'b') && (tofs_tmp[5] == 'l') && (tofs_tmp[6] == 'k'))
+			)
+			{
+				if(verify == true)
+				{
+					fprintf(stderr, "コピー先のファイルシステムがNTFSかつ、ベリファイオプションが有効です。\n");
+					fprintf(stderr, "終了します。\n");
+					exit(EXIT_FAILURE);
+				}
+			}
+		}
+
+		filesystem_check = true;
+	}
+
 	cpinfo->from_size = 0;
 	cpinfo->to_size = 0;
 
@@ -219,6 +257,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		{
 			from_stat = true;
 			from_size_local = stat_buf.st_size;
+			cpdd->total_source += from_size_local;
 		}
 
 		if((cpinfo->file_test == false) || (oparg->WRITE_MODE == OVERWRITE))
@@ -272,30 +311,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		}
 	}
 
-	if(filesystem_check == false)
-	{
-		char *tofs_tmp = cpinfo->tofs;
-
-		if(tofs_tmp != NULL)
-		{
-			if
-			(
-				((tofs_tmp[0] == 'e') && (tofs_tmp[1] == 'x') && (tofs_tmp[2] == 't') && (tofs_tmp[3] == '4'))
-				||
-				((tofs_tmp[0] == 'x') && (tofs_tmp[1] == 'f') && (tofs_tmp[2] == 's'))
-				||
-				((tofs_tmp[0] == 'b') && (tofs_tmp[1] == 't') && (tofs_tmp[2] == 'r') && (tofs_tmp[2] == 'f') && (tofs_tmp[2] == 's'))
-				||
-				((tofs_tmp[0] == 'o') && (tofs_tmp[1] == 'c') && (tofs_tmp[2] == 'f') && (tofs_tmp[2] == 's') && (tofs_tmp[2] == '2'))
-			)
-			{
-				fallocate_support = true;
-			}
-		}
-
-		filesystem_check = true;
-	}
-
 	/*
 	 * ファイルシステムがfallocateをサポートしている場合、それを実行して領域を確保する。
 	 * 
@@ -715,7 +730,7 @@ LOOP_END:
 			}
 			else if((to_open == true) && (from_size_local > 0))
 			{
-				verify_hash(oparg, cpinfo, sdir, cpdd);
+				verify_hash(oparg, sdir, cpinfo, cpdd);
 			}
 			else
 			{
