@@ -1,17 +1,15 @@
 #include "analyze_argument.h"
+#include "check_target.h"
 #include "compare_hash.h"
 #include "get_drive_list.h"
-#include "get_file_list.h"
 #include "get_settings_dir.h"
 #include "help.h"
 #include "print_error.h" // inline
-#include "process_file_list.h"
 #include "read_conf.h"
 #include "set_signal.h"
 #include "struct_CPDD.h"
 #include "struct_DPath.h"
 #include "struct_OPArg.h"
-#include "struct_SData.h"
 #include "verify_hash.h"
 #include "write_conf.h"
 
@@ -69,20 +67,14 @@ int main(int argc, char **argv)
 	VList *drive_list = get_drive_list();
 	set_signal();
 
-	puts("コピー対象の一覧を作成中です...");
+	puts("コピーを開始します...");
 
-	SData *sdata = get_file_list(oparg, drive_list);
-	VList *file_list = sdata->file_list;
-	CPDD *cpdd = sdata->cpdd;
+	RData *rdata = check_target(oparg, drive_list, sdir);
 
-	if(file_list != NULL)
-	{
-		puts("コピーを開始します...");
+	puts("コピーを完了しました...");
 
-		process_file_list(oparg, file_list, sdir, cpdd);
-
-		puts("コピーを完了しました...");
-	}
+	VList *file_list = rdata->file_list;
+	CPDD *cpdd = rdata->cpdd;
 
 	if((file_list != NULL) && (oparg->CHECK_MODE == AFTER) && (cpdd->mk_file_count > 0))
 	{
@@ -138,7 +130,7 @@ int main(int argc, char **argv)
 {\
 	if(cpinfo->write == true)\
 	{\
-		compare_hash(oparg, cpinfo, sdir, cpdd);\
+		compare_hash(oparg, sdir, cpinfo, cpdd);\
 	}\
 	else if((cpinfo->write == false) && (cpinfo->skip == false))\
 	{\
@@ -196,7 +188,7 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 				}
 				else
 				{
-					verify_hash(oparg, cpinfo, sdir, cpdd);
+					verify_hash(oparg, sdir, cpinfo, cpdd);
 				}
 				break;
 
@@ -261,6 +253,10 @@ static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD
 				{
 					FILE_REMOVE
 				}
+				else if((cpinfo->write == true) && (cpinfo->from_size == 0) && (cpinfo->to_size == 0))
+				{
+					FILE_REMOVE
+				}
 			}
 			break;
 
